@@ -110,6 +110,8 @@ def subscriptions(ctx, base_url):
     '--destination-ref',
     help="Filter subscriptions created with the provided destination reference."
 )
+@click.option('--user-id',
+              help="Filter by user ID. Accepts 'all' or a specific user ID.")
 @limit
 @click.option('--page-size',
               type=click.INT,
@@ -130,6 +132,7 @@ async def list_subscriptions_cmd(ctx,
                                  updated,
                                  limit,
                                  destination_ref,
+                                 user_id,
                                  page_size,
                                  pretty):
     """Prints a sequence of JSON-encoded Subscription descriptions."""
@@ -146,7 +149,8 @@ async def list_subscriptions_cmd(ctx,
             'sort_by': sort_by,
             'updated': updated,
             'limit': limit,
-            'destination_ref': destination_ref
+            'destination_ref': destination_ref,
+            'user_id': user_id
         }
         if page_size is not None:
             list_subscriptions_kwargs['page_size'] = page_size
