@@ -16,7 +16,7 @@
 import asyncio
 import logging
 import time
-from typing import AsyncIterator, Callable, Dict, List, Optional, Sequence, TypeVar, Union
+from typing import Any, AsyncIterator, Callable, Dict, List, Optional, TypeVar, Union
 import uuid
 import json
 import hashlib
@@ -474,7 +474,8 @@ class OrdersClient(_BaseClient):
             last_modified: Optional[str] = None,
             hosting: Optional[bool] = None,
             destination_ref: Optional[str] = None,
-            sort_by: Optional[str] = None) -> AsyncIterator[dict]:
+            sort_by: Optional[str] = None,
+            user_id: Optional[Union[str, int]] = None) -> AsyncIterator[dict]:
         """Iterate over the list of stored orders.
 
         By default, order descriptions are sorted by creation date with the last created
@@ -510,6 +511,8 @@ class OrdersClient(_BaseClient):
                  * "name"
                  * "name DESC"
                  * "name,state DESC,last_modified"
+            user_id (str or int): filter by user ID. Only available to organization admins.
+                Accepts "all" or a specific user ID.
 
         Datetime args (created_on and last_modified) can either be a date-time or an
         interval, open or closed. Date and time expressions adhere to RFC 3339. Open
@@ -528,7 +531,7 @@ class OrdersClient(_BaseClient):
             planet.exceptions.ClientError: If state is not valid.
         """
         url = self._orders_url()
-        params: Dict[str, Union[str, Sequence[str], bool]] = {}
+        params: Dict[str, Any] = {}
         if source_type is not None:
             params["source_type"] = source_type
         else:
@@ -547,6 +550,8 @@ class OrdersClient(_BaseClient):
             params["sort_by"] = sort_by
         if destination_ref is not None:
             params["destination_ref"] = destination_ref
+        if user_id is not None:
+            params["user_id"] = user_id
         if state:
             if state not in ORDER_STATE_SEQUENCE:
                 raise exceptions.ClientError(
