@@ -312,6 +312,18 @@ async def test_list_subscriptions_filtering_and_sorting():
         ]) == 2
 
 
+@pytest.mark.parametrize("user_id", ["all", "123", 456])
+@pytest.mark.anyio
+@api_mock
+async def test_list_subscriptions_user_id_filtering(user_id):
+    """Test user_id parameter filtering for organization admins."""
+    async with Session() as session:
+        client = SubscriptionsClient(session, base_url=TEST_URL)
+        assert len([
+            sub async for sub in client.list_subscriptions(user_id=user_id)
+        ]) == 100
+
+
 @pytest.mark.parametrize("page_size, count", [(50, 100), (100, 100)])
 @pytest.mark.anyio
 @api_mock
